==> kdepim-4.1.2.tar.bz2: kdepim-4.1.2/kaddressbook/kcmconfigs/addhostdialog.h <==
/*
    This file is part of KAddressBook.
    Copyright (c) 2002 Tobias Koenig <tokoe@kde.org>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.

    As a special exception, permission is given to link this program
    with any edition of Qt, and distribute the resulting executable,
    without including the source code for Qt in the source distribution.
*/

#ifndef ADDHOSTDIALOG_H
#define ADDHOSTDIALOG_H

#include <kdialog.h>
#include <kldap/ldapserver.h>
#include <kldap/ldapconfigwidget.h>
#include <libkdepim/ldapclient.h>


class AddHostDialog : public KDialog
{
    Q_OBJECT

  public:
    AddHostDialog( KLDAP::LdapServer* server, QWidget* parent = 0 );
    ~AddHostDialog();

  signals:
    void changed( bool );

  private slots:
    void slotHostEditChanged( const QString& );
    virtual void slotOk();
  private:
    KLDAP::LdapConfigWidget *mCfg;
    KLDAP::LdapServer *mServer;
};

#endif // ADDHOSTDIALOG_H

==> kdepim-4.2.2.tar.bz2: kdepim-4.2.2/kaddressbook/kcmconfigs/addhostdialog.h <==
/*
    This file is part of KAddressBook.
    Copyright (c) 2002 Tobias Koenig <tokoe@kde.org>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.

    As a special exception, permission is given to link this program
    with any edition of Qt, and distribute the resulting executable,
    without including the source code for Qt in the source distribution.
*/

#ifndef ADDHOSTDIALOG_H
#define ADDHOSTDIALOG_H

#include <kdialog.h>

namespace KLDAP {
class LdapConfigWidget;
class LdapServer;
}

class AddHostDialog : public KDialog
{
    Q_OBJECT

  public:
    explicit AddHostDialog( KLDAP::LdapServer* server, QWidget* parent = 0 );
    ~AddHostDialog();

  Q_SIGNALS:
    void changed( bool );

  private Q_SLOTS:
    void slotHostEditChanged( const QString& );
    virtual void slotOk();

  private:
    KLDAP::LdapConfigWidget *mCfg;
    KLDAP::LdapServer *mServer;
};

#endif // ADDHOSTDIALOG_H
